Class: ArrowFormat::Org::Apache::Arrow::Flatbuf::BinaryView

Inherits:
FlatBuffers::Table
  • Object
show all
Defined in:
lib/arrow-format/org/apache/arrow/flatbuf/binary_view.rb

Overview

Logically the same as Binary, but the internal representation uses a view struct that contains the string length and either the string’s entire data inline (for small strings) or an inlined prefix, an index of another buffer, and an offset pointing to a slice in that buffer (for non-small strings).

Since it uses a variable number of data buffers, each Field with this type must have a corresponding entry in ‘variadicBufferCounts`.

Constant Summary collapse

FIELDS =
{
}
Data =
define_data_class