Class: ArrowFormat::Org::Apache::Arrow::Flatbuf::Block
- Inherits:
-
FlatBuffers::Struct
- Object
- FlatBuffers::Struct
- ArrowFormat::Org::Apache::Arrow::Flatbuf::Block
- Defined in:
- lib/arrow-format/org/apache/arrow/flatbuf/block.rb
Constant Summary collapse
- FIELDS =
{ offset: ::FlatBuffers::Field.new(:offset, 0, 0, :long, 0), meta_data_length: ::FlatBuffers::Field.new(:meta_data_length, 1, 8, :int, 4), body_length: ::FlatBuffers::Field.new(:body_length, 2, 16, :long, 0), }
- Data =
define_data_class
Instance Method Summary collapse
-
#body_length ⇒ Object
Length of the data (this is aligned so there can be a gap between this and the metadata).
-
#meta_data_length ⇒ Object
Length of the metadata.
-
#offset ⇒ Object
Index to the start of the RecordBatch (note this is past the Message header).
Instance Method Details
#body_length ⇒ Object
Length of the data (this is aligned so there can be a gap between this and the metadata).
25 26 27 28 |
# File 'lib/arrow-format/org/apache/arrow/flatbuf/block.rb', line 25 def body_length field_offset = 16 @view.unpack_long(field_offset) end |
#meta_data_length ⇒ Object
Length of the metadata
31 32 33 34 |
# File 'lib/arrow-format/org/apache/arrow/flatbuf/block.rb', line 31 def field_offset = 8 @view.unpack_int(field_offset) end |
#offset ⇒ Object
Index to the start of the RecordBatch (note this is past the Message header)
37 38 39 40 |
# File 'lib/arrow-format/org/apache/arrow/flatbuf/block.rb', line 37 def offset field_offset = 0 @view.unpack_long(field_offset) end |