Class: ArrowFormat::Org::Apache::Arrow::Flatbuf::DictionaryKind

Inherits:
FlatBuffers::Enum
  • Object
show all
Defined in:
lib/arrow-format/org/apache/arrow/flatbuf/dictionary_kind.rb

Overview


Dictionary encoding metadata Maintained for forwards compatibility, in the future Dictionaries might be explicit maps between integers and values allowing for non-contiguous index values

Constant Summary collapse

DENSE_ARRAY =
register("DenseArray", 0)