Class: ArrowFormat::Org::Apache::Arrow::Flatbuf::FieldNode

Inherits:
FlatBuffers::Struct
  • Object
show all
Defined in:
lib/arrow-format/org/apache/arrow/flatbuf/field_node.rb

Overview


Data structures for describing a table row batch (a collection of equal-length Arrow arrays) Metadata about a field at some level of a nested type tree (but not its children).

For example, a List<Int16> with values ‘[[1, 2, 3], null, [4], [5, 6], null]` would have 5, null_count: 2 for its List node, and 6, null_count: 0 for its Int16 node, as separate FieldNode structs

Constant Summary collapse

FIELDS =
{
  length: ::FlatBuffers::Field.new(:length, 0, 0, :long, 0),
  null_count: ::FlatBuffers::Field.new(:null_count, 1, 8, :long, 0),
}
Data =
define_data_class

Instance Method Summary collapse

Instance Method Details

#lengthObject

The number of value slots in the Arrow array at this level of a nested tree



33
34
35
36
# File 'lib/arrow-format/org/apache/arrow/flatbuf/field_node.rb', line 33

def length
  field_offset = 0
  @view.unpack_long(field_offset)
end

#null_countObject

The number of observed nulls. Fields with null_count == 0 may choose not to write their physical validity bitmap out as a materialized buffer, instead setting the length of the bitmap buffer to 0.



41
42
43
44
# File 'lib/arrow-format/org/apache/arrow/flatbuf/field_node.rb', line 41

def null_count
  field_offset = 8
  @view.unpack_long(field_offset)
end