Class: ArrowFormat::Org::Apache::Arrow::Flatbuf::ListView

Inherits:
FlatBuffers::Table
  • Object
show all
Defined in:
lib/arrow-format/org/apache/arrow/flatbuf/list_view.rb

Overview

Represents the same logical types that List can, but contains offsets and sizes allowing for writes in any order and sharing of child values among list values.

Constant Summary collapse

FIELDS =
{
}
Data =
define_data_class