Class: ArrowFormat::Org::Apache::Arrow::Flatbuf::Struct

Inherits:
FlatBuffers::Table
  • Object
show all
Defined in:
lib/arrow-format/org/apache/arrow/flatbuf/struct_.rb

Overview

A Struct_ in the flatbuffer metadata is the same as an Arrow Struct (according to the physical memory layout). We used Struct_ here as Struct is a reserved word in Flatbuffers

Constant Summary collapse

FIELDS =
{
}
Data =
define_data_class