Class: ArrowFormat::Org::Apache::Arrow::Flatbuf::Feature
- Inherits:
-
FlatBuffers::Enum
- Object
- FlatBuffers::Enum
- ArrowFormat::Org::Apache::Arrow::Flatbuf::Feature
- Defined in:
- lib/arrow-format/org/apache/arrow/flatbuf/feature.rb
Overview
Represents Arrow Features that might not have full support within implementations. This is intended to be used in two scenarios:
- A mechanism for readers of Arrow Streams and files to understand that the stream or file makes use of a feature that isn't supported or unknown to the implementation (and therefore can meet the Arrow forward compatibility guarantees).
- A means of negotiating between a client and server what features a stream is allowed to use. The enums values here are intended to represent higher level features, additional details may be negotiated with key-value pairs specific to the protocol.
Enums added to this list should be assigned power-of-two values to facilitate exchanging and comparing bitmaps for supported features.
Constant Summary collapse
- UNUSED =
Needed to make flatbuffers happy.
register("UNUSED", 0)
- DICTIONARY_REPLACEMENT =
The stream makes use of multiple full dictionaries with the same ID and assumes clients implement dictionary replacement correctly.
register("DICTIONARY_REPLACEMENT", 1)
- COMPRESSED_BODY =
The stream makes use of compressed bodies as described in Message.fbs.
register("COMPRESSED_BODY", 2)