Class: ArrowFormat::Org::Apache::Arrow::Flatbuf::RunEndEncoded
- Inherits:
-
FlatBuffers::Table
- Object
- FlatBuffers::Table
- ArrowFormat::Org::Apache::Arrow::Flatbuf::RunEndEncoded
- Defined in:
- lib/arrow-format/org/apache/arrow/flatbuf/run_end_encoded.rb
Overview
Contains two child arrays, run_ends and values. The run_ends child array must be a 16/32/64-bit integer array which encodes the indices at which the run with the value in each corresponding index in the values child array ends. Like list/struct types, the value array can be of any type.
Constant Summary collapse
- FIELDS =
{ }
- Data =
define_data_class